#!/bin/bash

# Check that we've been supplied a valid version
VERSION="$1"
if [ "$VERSION" == "" ]; then
  echo -e "You must supply a version tag like './build_deb.sh 1.2.3'."
  exit 1
fi
# Trim the leading 'v' from version number
if [[ "${VERSION:0:1}" == "v" ]]; then
  VERSION="${VERSION:1}"
fi

# Create workspace for our deb package
WORKDIR="adept_$VERSION"
mkdir "$WORKDIR"

# Copy build sources into workspace
cp -r build/etc "$WORKDIR/"
mkdir -p "$WORKDIR/usr/bin/"
cp "dist/adept-linux-amd64-v$VERSION" "$WORKDIR/usr/bin/adept"

# Create debian control file
mkdir "$WORKDIR/DEBIAN"
cat > "$WORKDIR/DEBIAN/control"<< EOF
Package: adept
Version: $VERSION
Section: video
Priority: optional
Architecture: amd64
Depends: ffmpeg (>= 4), lsof
Maintainer: Gregory Ballantine <gballantine@bitgoblin.tech>
Description: Bit Goblin video transcoding service.
EOF
# Copy maintainer scripts
cp build/scripts/* "$WORKDIR/DEBIAN/"
#chmod +rx "$WORKDIR"/DEBIAN/pre*
chmod +rx "$WORKDIR"/DEBIAN/post*

# Build deb package!
dpkg-deb --build "$WORKDIR"

# Cleanup
rm -rf "$WORKDIR"
